include "src/gb.inc"
include "src/global.inc"

section "ram_main", WRAM0
nmis:: ds 1

section "rom_main", ROM0

; Double-colon these so that the header can see them
stat_handler::
timer_handler::
serial_handler::
joypad_handler::
  reti

vblank_handler::
  push af
  ld a,[nmis]
  inc a
  ld [nmis],a
  pop af
  reti

main::
  ; Avoid uninitialized read warnings for nmis and cur_keys
  xor a
  ld [nmis],a
  ; set all keys so that first read_pad returns none new
  dec a
  ld [cur_keys],a

  ; Set up vblank handler
  ld a,IF_VBLANK
  ldh [IRQE],a  ; enable IRQs
  xor a
  ldh [IRQF],a  ; Acknowledge any pending IRQs
  ei

  call draw_bg
  call load_player_cels

  ; Can turn on rendering at any time.  Only turning off
  ; rendering is time restricted.  GB LCD freesync is backwards
  ; from traditional NES/Super NES video in this way.
  ld a,LCD_ON|BG_ON|OBJ_ON|BG_NT0|BG_CHR21
  ld [LCDC],a

.loop:
  call read_pad
  call move_player

  ; First make sure it doesn't crash
  xor a
  ld [oam_used],a
  call draw_player_sprite
  call lcd_clear_oam

  call wait_vblank_irq
  call run_dma
  ld hl,NTRAM0
  ld a,[nmis]
  call puthex

  jr .loop
